pub enum Error {
Parse {
message: String,
line: Option<u32>,
property: Option<String>,
},
}Variants
Implementations
Sourceimpl Error
impl Error
Sourcepub fn parse(message: impl Into<String>) -> Self
pub fn parse(message: impl Into<String>) -> Self
Construct a Parse error from a plain message with no line / property
context. Use parse_at_line when a logical line number is available.
Sourcepub fn parse_at_line(line: u32, message: impl Into<String>) -> Self
pub fn parse_at_line(line: u32, message: impl Into<String>) -> Self
Construct a Parse error attached to a specific 1-based logical
line number.